==> ath1121501_1.8.2.tar.gz: ath1121501/man/ath1121501PMID.Rd <==
\name{ath1121501PMID}
\alias{ath1121501PMID}
\title{Map between Manufacturer Identifiers and PubMed Identifiers}
\description{
   ath1121501PMID is an R environment that provides mappings between
   manufacturer ids and PubMed ids.
}
\details{
  Each manufacturer id is mapped to a named vector of PubMed ids. The
  name associated with each vector corresponds to the manufacturer
  id. The length of the vector may be one or greater, depending on how
  many PubMed ids a given manufacturer id is mapped to. An \code{NA} is
  reported for any manufacturer id that cannot be mapped to a PubMed id.

  Titles, abstracts, and possibly full texts of articles can be obtained
  from PubMed by providing a valid PubMed id. The pubmed function of
  annotate can also be used for the same purpose.

  Mappings were based on data provided by:

  Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Genes/gene_aliases.20041105}
Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Genes/TAIR_sequenced_genes}
Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Genes/Gene_Anatomy/ATH_Anatomy.20040209.txt}
Built: N/A

  Package built Tue May 17 18:45:34 2005
}
\references{
  \url{http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=PubMed}
}
\examples{
    # Convert the environment to a list
    xx <- as.list(ath1121501PMID)
    if(length(xx) > 0){
        # The probe ids for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
        if(interactive() && !is.null(xx[[1]]) && !is.na(xx[[1]])
           && require(annotate)){
            # Gets article information as XML files
            xmls <- pubmed(xx[[1]], disp = "data")
            # Views article information using a browser
            pubmed(xx[[1]], disp = "browser")
        }
    }
}
\keyword{datasets}

==> ath1121501_1.10.0.tar.gz: ath1121501/man/ath1121501PMID.Rd <==
\name{ath1121501PMID}
\alias{ath1121501PMID}
\title{Map between Manufacturer Identifiers and PubMed Identifiers}
\description{
   ath1121501PMID is an R environment that provides mappings between
   manufacturer ids and PubMed ids.
}
\details{
  Each manufacturer id is mapped to a named vector of PubMed ids. The
  name associated with each vector corresponds to the manufacturer
  id. The length of the vector may be one or greater, depending on how
  many PubMed ids a given manufacturer id is mapped to. An \code{NA} is
  reported for any manufacturer id that cannot be mapped to a PubMed id.

  Titles, abstracts, and possibly full texts of articles can be obtained
  from PubMed by providing a valid PubMed id. The pubmed function of
  annotate can also be used for the same purpose.

  Mappings were based on data provided by:

  Tair: \url{http://gopher5/compbio/annotationSourceData/ftp.arabidopsis.org/home/tair/Genes/gene_aliases.20041105}
Tair: \url{http://gopher5/compbio/annotationSourceData/ftp.arabidopsis.org/home/tair/Genes/TAIR_sequenced_genes}
Tair: \url{http://gopher5/compbio/annotationSourceData/ftp.arabidopsis.org/home/tair/Ontologies/TAIR_Ontology/ATH_anatomy.20050119.txt}
Built: N/A

  Package built Tue Oct  4 19:05:27 2005
}
\references{
  \url{http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?db=PubMed}
}
\examples{
    # Convert the environment to a list
    xx <- as.list(ath1121501PMID)
    if(length(xx) > 0){
        # The probe ids for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
        if(interactive() && !is.null(xx[[1]]) && !is.na(xx[[1]])
           && require(annotate)){
            # Gets article information as XML files
            xmls <- pubmed(xx[[1]], disp = "data")
            # Views article information using a browser
            pubmed(xx[[1]], disp = "browser")
        }
    }
}
\keyword{datasets}
